RecommenderXBlock
=================

This XBlock shows students a list of recommended resources for a given
problem. The resources are recommended, edited, and voted by students.
For each resource, we show its title, link, short summary, preview
screenshot, and votes:

.. image:: recommender_xblock.png
   :alt: Recommender screenshot

This is an module where students can share useful resources/hints and rate
them. This crowdsourcing mechanism allows a scalable solution to fulfill
students with varying learning needs.

* Staff Interface: manage problematic resourse easier, add comments, endorse,
  de-endorse resource
* Discussion around each resource
* Better interface for adding varying types of resource (e.g., specific timestamps
  in the video or specific elements in a learning sequence)
* Better user help/documentation
* Tag/categorize resources around specific misconceptions

In a randomized control trial in a computer science course, this XBlock led to 
similar learning outcomes in about 10% less time than without it (so efficiency of 
learning was about 10% better than without the XBlock -- students learned the same
in less time). Qualitative analysis as well as quantitative analysis of usage data 
showed it was helpful in contexts where there were complex, multiconcept problems. 
It was not helpful or used in contexts where there were simple, single-step problems. 

In an analysis comparing to other remediation systems within edX, it was more 
effective for deeper, more complex misconceptions, and less effective for simple 
errors. 
